outatime: Python framework to manage time series
#######################################################################

.. include:: README.rst
    :start-after: .. _start-badges-list:
    :end-before: .. _end-badges-list:

.. include:: README.rst
    :start-after: .. _start-0-pypi:
    :end-before: .. _end-0-pypi:

.. include:: README.rst
    :start-after: .. _start-install:
    :end-before: .. _end-install:

.. include:: README.rst
    :start-after: .. _start-badges:
    :end-before: .. _end-badges:
